LD) or unphased (LD2) genotypes.LD(x, locus = 1:2, details = TRUE)
LD2(x, locus = 1:2, details = TRUE)"loci".details = FALSE, only the T2 test is
returned. For LD: if details = TRUE, a named list with the
following elements:
LD2: if details = TRUE, a named list with two
elements: LD first scans the data for unphased genotypes: all individuals
with at least one unphased genotype are dropped with a warning. It is
based on the observed frequencies of haplotypes (Zaykin et
al. 2008). LD2 is based on the observed frequencies of
different genotypes (Schaid 2004).
Both functions accept any number of alleles. LD can work with
any level of ploidy; LD2 works with diploid data.
The present version does not test the significance of the $T_2$ test (Zaykin et al. 2008) with permutations. These authors present simulation results suggesting that the chi-squared approximation has similar type I error rates and power than the test based on permutations even for small sample sizes. Furthermore, this test has better statistical properties than alternatives such as those reported here (LRT and Pearson's test).
Zaykin, D. V., Pudovkin, A. and Weir, B. S. (2008) Correlation-based inference for linkage disequilibrium with multiple alleles. Genetics, 180, 533--545.
haplotype.loci, is.phaseddata(jaguar)
LD2(jaguar, details = FALSE)
LD2(jaguar, locus = 8:9, details = FALSE)Run the code above in your browser using DataLab