## S3 method for class 'loci':
haplotype(x, locus = 1:2, quiet = FALSE, ...)
## S3 method for class 'haplotype.loci':
plot(x, ...)
dist.haplotype.loci(x)"loci" or of class
"haplotype.loci".FALSE by default).haplotype returns a matrix of mode character with the loci as
rows and the haplotypes as columns. The attribute "freq" gives
the counts of each haplotype and the class is "haplotype.loci". dist.haplotype.loci returns an object of class "dist".
dist.haplotype.loci computes pairwise distances among
haplotypes by counting the number of different alleles.
haplotype, LD