read.loci(file, header = TRUE, loci.sep = "", allele.sep = "/|",
col.pop = NULL, col.loci = NULL, ...)TRUE by default).read.table (e.g.,
row.names).c("loci", "data.frame"). It is a data
frame with an attribute "locicol" specifying the columns that
must be treated as loci. The latter are factors. The other columns can
be of any type. Details on the structure can be found in
"1", "2", ...Similarly for the colnames: if
absent in the file (in which case header = FALSE must be set),
they are given the values "V1", "V2", ...In the returned genotypes, alleles are separated by "/", even
if it is not the case in the data file. The vignette ``Reading Genetic Data Files Into R with vignette("ReadingFiles") in R).
read.gtx, read.vcf,
write.loci, summary.loci